==> cloudwatch-1.60.0-sources.jar: software/amazon/awscdk/services/cloudwatch/MetricRenderingProperties.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * Custom rendering properties that override the default rendering properties specified in the yAxis parameter of the widget object.
 * <p>
 * @deprecated Replaced by MetricConfig.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:02.867Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudwatch.$Module.class, fqn = "@aws-cdk/aws-cloudwatch.MetricRenderingProperties")
@software.amazon.jsii.Jsii.Proxy(MetricRenderingProperties.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
public interface MetricRenderingProperties extends software.amazon.jsii.JsiiSerializable {

    /**
     * How many seconds to aggregate over.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @org.jetbrains.annotations.NotNull java.lang.Number getPeriod();

    /**
     * The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The `Color` class has a set of standard colors that can be used here.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.String getColor() {
        return null;
    }

    /**
     * Label for the metric.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.String getLabel() {
        return null;
    }

    /**
     * Aggregation function to use (can be either simple or a percentile).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.String getStat() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MetricRenderingProperties}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MetricRenderingProperties}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<MetricRenderingProperties> {
        private java.lang.Number period;
        private java.lang.String color;
        private java.lang.String label;
        private java.lang.String stat;

        /**
         * Sets the value of {@link MetricRenderingProperties#getPeriod}
         * @param period How many seconds to aggregate over. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder period(java.lang.Number period) {
            this.period = period;
            return this;
        }

        /**
         * Sets the value of {@link MetricRenderingProperties#getColor}
         * @param color The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The `Color` class has a set of standard colors that can be used here.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder color(java.lang.String color) {
            this.color = color;
            return this;
        }

        /**
         * Sets the value of {@link MetricRenderingProperties#getLabel}
         * @param label Label for the metric.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder label(java.lang.String label) {
            this.label = label;
            return this;
        }

        /**
         * Sets the value of {@link MetricRenderingProperties#getStat}
         * @param stat Aggregation function to use (can be either simple or a percentile).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder stat(java.lang.String stat) {
            this.stat = stat;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MetricRenderingProperties}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public MetricRenderingProperties build() {
            return new Jsii$Proxy(period, color, label, stat);
        }
    }

    /**
     * An implementation for {@link MetricRenderingProperties}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MetricRenderingProperties {
        private final java.lang.Number period;
        private final java.lang.String color;
        private final java.lang.String label;
        private final java.lang.String stat;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.period = this.jsiiGet("period", java.lang.Number.class);
            this.color = this.jsiiGet("color", java.lang.String.class);
            this.label = this.jsiiGet("label", java.lang.String.class);
            this.stat = this.jsiiGet("stat", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.Number period, final java.lang.String color, final java.lang.String label, final java.lang.String stat) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.period = java.util.Objects.requireNonNull(period, "period is required");
            this.color = color;
            this.label = label;
            this.stat = stat;
        }

        @Override
        public java.lang.Number getPeriod() {
            return this.period;
        }

        @Override
        public java.lang.String getColor() {
            return this.color;
        }

        @Override
        public java.lang.String getLabel() {
            return this.label;
        }

        @Override
        public java.lang.String getStat() {
            return this.stat;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("period", om.valueToTree(this.getPeriod()));
            if (this.getColor() != null) {
                data.set("color", om.valueToTree(this.getColor()));
            }
            if (this.getLabel() != null) {
                data.set("label", om.valueToTree(this.getLabel()));
            }
            if (this.getStat() != null) {
                data.set("stat", om.valueToTree(this.getStat()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudwatch.MetricRenderingProperties"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MetricRenderingProperties.Jsii$Proxy that = (MetricRenderingProperties.Jsii$Proxy) o;

            if (!period.equals(that.period)) return false;
            if (this.color != null ? !this.color.equals(that.color) : that.color != null) return false;
            if (this.label != null ? !this.label.equals(that.label) : that.label != null) return false;
            return this.stat != null ? this.stat.equals(that.stat) : that.stat == null;
        }

        @Override
        public int hashCode() {
            int result = this.period.hashCode();
            result = 31 * result + (this.color != null ? this.color.hashCode() : 0);
            result = 31 * result + (this.label != null ? this.label.hashCode() : 0);
            result = 31 * result + (this.stat != null ? this.stat.hashCode() : 0);
            return result;
        }
    }
}

==> cloudwatch-1.93.0-sources.jar: software/amazon/awscdk/services/cloudwatch/MetricRenderingProperties.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * (deprecated) Custom rendering properties that override the default rendering properties specified in the yAxis parameter of the widget object.
 * <p>
 * @deprecated Replaced by MetricConfig.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:22.303Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudwatch.$Module.class, fqn = "@aws-cdk/aws-cloudwatch.MetricRenderingProperties")
@software.amazon.jsii.Jsii.Proxy(MetricRenderingProperties.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
public interface MetricRenderingProperties extends software.amazon.jsii.JsiiSerializable {

    /**
     * (deprecated) How many seconds to aggregate over.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @org.jetbrains.annotations.NotNull java.lang.Number getPeriod();

    /**
     * (deprecated) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The `Color` class has a set of standard colors that can be used here.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.String getColor() {
        return null;
    }

    /**
     * (deprecated) Label for the metric.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.String getLabel() {
        return null;
    }

    /**
     * (deprecated) Aggregation function to use (can be either simple or a percentile).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.String getStat() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MetricRenderingProperties}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MetricRenderingProperties}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<MetricRenderingProperties> {
        private java.lang.Number period;
        private java.lang.String color;
        private java.lang.String label;
        private java.lang.String stat;

        /**
         * Sets the value of {@link MetricRenderingProperties#getPeriod}
         * @param period How many seconds to aggregate over. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder period(java.lang.Number period) {
            this.period = period;
            return this;
        }

        /**
         * Sets the value of {@link MetricRenderingProperties#getColor}
         * @param color The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The `Color` class has a set of standard colors that can be used here.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder color(java.lang.String color) {
            this.color = color;
            return this;
        }

        /**
         * Sets the value of {@link MetricRenderingProperties#getLabel}
         * @param label Label for the metric.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder label(java.lang.String label) {
            this.label = label;
            return this;
        }

        /**
         * Sets the value of {@link MetricRenderingProperties#getStat}
         * @param stat Aggregation function to use (can be either simple or a percentile).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder stat(java.lang.String stat) {
            this.stat = stat;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MetricRenderingProperties}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public MetricRenderingProperties build() {
            return new Jsii$Proxy(period, color, label, stat);
        }
    }

    /**
     * An implementation for {@link MetricRenderingProperties}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MetricRenderingProperties {
        private final java.lang.Number period;
        private final java.lang.String color;
        private final java.lang.String label;
        private final java.lang.String stat;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.period = software.amazon.jsii.Kernel.get(this, "period", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.color = software.amazon.jsii.Kernel.get(this, "color", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.label = software.amazon.jsii.Kernel.get(this, "label", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.stat = software.amazon.jsii.Kernel.get(this, "stat", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.Number period, final java.lang.String color, final java.lang.String label, final java.lang.String stat) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.period = java.util.Objects.requireNonNull(period, "period is required");
            this.color = color;
            this.label = label;
            this.stat = stat;
        }

        @Override
        public final java.lang.Number getPeriod() {
            return this.period;
        }

        @Override
        public final java.lang.String getColor() {
            return this.color;
        }

        @Override
        public final java.lang.String getLabel() {
            return this.label;
        }

        @Override
        public final java.lang.String getStat() {
            return this.stat;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("period", om.valueToTree(this.getPeriod()));
            if (this.getColor() != null) {
                data.set("color", om.valueToTree(this.getColor()));
            }
            if (this.getLabel() != null) {
                data.set("label", om.valueToTree(this.getLabel()));
            }
            if (this.getStat() != null) {
                data.set("stat", om.valueToTree(this.getStat()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudwatch.MetricRenderingProperties"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MetricRenderingProperties.Jsii$Proxy that = (MetricRenderingProperties.Jsii$Proxy) o;

            if (!period.equals(that.period)) return false;
            if (this.color != null ? !this.color.equals(that.color) : that.color != null) return false;
            if (this.label != null ? !this.label.equals(that.label) : that.label != null) return false;
            return this.stat != null ? this.stat.equals(that.stat) : that.stat == null;
        }

        @Override
        public final int hashCode() {
            int result = this.period.hashCode();
            result = 31 * result + (this.color != null ? this.color.hashCode() : 0);
            result = 31 * result + (this.label != null ? this.label.hashCode() : 0);
            result = 31 * result + (this.stat != null ? this.stat.hashCode() : 0);
            return result;
        }
    }
}
